@@ -132,7 +132,6 @@ class MailProcessorTest(TestCase):
         stacktrace.get_title.assert_called_once_with()
         stacktrace.to_string.assert_called_once_with(event)
 
-
     @mock.patch('sentry.plugins.sentry_mail.models.MailProcessor._send_mail')
     def test_notify_users_does_email(self, _send_mail):
         project = Project(id=1, name='Project Name')
@@ -185,55 +184,89 @@ class MailProcessorTest(TestCase):
         args, kwargs = _send_mail.call_args
         self.assertEquals(kwargs.get('subject'), u"[Project Name] ERROR: hello world")
 
-    def test_send_to(self):
-        Mock = mock.Mock
-        with mock.patch('sentry.models.ProjectOption.objects.get_value') as get_value:
-            opts = {}
-            get_value.side_effect = lambda p, k, d: opts.get(k, d)
+    @mock.patch('sentry.utils.cache.cache.get', mock.Mock(return_value=None))
+    @mock.patch('sentry.models.ProjectOption.objects.get_value')
+    @mock.patch('sentry.plugins.sentry_mail.models.MailProcessor.get_sendable_users')
+    @mock.patch('sentry.plugins.sentry_mail.models.MailProcessor.get_emails_for_users')
+    def test_send_to(self, get_emails_for_users, get_sendable_users, get_value):
+        opts = {}
 
-            admins = ['admin@fake.com']
-            member_emails = ['test@fake.com', 'member@fake.com']
-            project_emails = ['member@fake.com', 'new@fake.com']
+        admins = ['1']
+        member_emails = ['2', '3']
+        project_emails = ['2', '4']
 
-            project = Mock()
-            project.team.member_set = Mock()
-            project.team.member_set.values_list.return_value = member_emails
+        get_value.side_effect = lambda p, k, d: opts.get(k, d)
+        get_emails_for_users.side_effect = lambda x: x
+        get_sendable_users.return_value = member_emails
 
-            with self.Settings(SENTRY_ADMINS=admins):
-                # member emails without admins
-                p = MailProcessor()
-                self.assertEqual(sorted(set(member_emails)),
-                                 sorted(p.get_send_to(project)))
+        project = mock.Mock()
+        project.id = 1
+        project.pk = project.id
 
-                # member emails with members
-                p = MailProcessor()
-                opts = {'mail:send_to_admins': True}
-                p._send_mail('', '', project=project)
-                self.assertEqual(sorted(set(member_emails + admins)),
-                                 sorted(p.get_send_to(project)))
+        with self.Settings(SENTRY_ADMINS=admins):
+            p = MailProcessor()
+            # member emails without admins
+            self.assertEqual(sorted(set(member_emails)),
+                             sorted(p.get_send_to(project)))
 
-                # project emails without members
-                p = MailProcessor()
-                opts = {'mail:send_to': ','.join(project_emails),
-                        'mail:send_to_members': False}
-                p._send_mail('', '', project=project)
-                self.assertEqual(sorted(set(project_emails)),
-                                 sorted(p.get_send_to(project)))
+            # member emails with members
+            opts = {'mail:send_to_admins': True}
+            self.assertEqual(sorted(set(member_emails + admins)),
+                             sorted(p.get_send_to(project)))
 
-                # project emails with members
-                p = MailProcessor()
-                opts = {'mail:send_to': ','.join(project_emails),
-                        'mail:send_to_members': False,
-                        'mail:send_to_admins': True}
-                p._send_mail('', '', project=project)
-                self.assertEqual(sorted(set(project_emails + admins)),
-                                 sorted(p.get_send_to(project)))
+            # project emails without members
+            opts = {'mail:send_to': ','.join(project_emails),
+                    'mail:send_to_members': False}
+            self.assertEqual(sorted(set(project_emails)),
+                             sorted(p.get_send_to(project)))
 
-                # project emails with members and admins
-                p = MailProcessor()
-                opts = {'mail:send_to': ','.join(project_emails),
-                        'mail:send_to_members': True,
-                        'mail:send_to_admins': True}
-                p._send_mail('', '', project=project)
-                self.assertEqual(sorted(set(project_emails + admins + member_emails)),
-                                 sorted(p.get_send_to(project)))
+            # project emails with members
+            opts = {'mail:send_to': ','.join(project_emails),
+                    'mail:send_to_members': False,
+                    'mail:send_to_admins': True}
+            self.assertEqual(sorted(set(project_emails + admins)),
+                             sorted(p.get_send_to(project)))
+
+            # project emails with members and admins
+            opts = {'mail:send_to': ','.join(project_emails),
+                    'mail:send_to_members': True,
+                    'mail:send_to_admins': True}
+            self.assertEqual(sorted(set(project_emails + admins + member_emails)),
+                             sorted(p.get_send_to(project)))
+
+    def test_get_emails_for_users(self):
+        from django.contrib.auth.models import User
+        from sentry.models import UserOption
+
+        user = User.objects.create(username='foo', email='foo@example.com')
+        user2 = User.objects.create(username='baz', email='baz@example.com')
+
+        p = MailProcessor()
+
+        self.assertEquals(sorted(p.get_emails_for_users([user.pk, user2.pk])),
+                          sorted([user.email, user2.email]))
+        UserOption.objects.create(key='alert_email', value='foobaz@example.com', user=user2)
+
+        self.assertEquals(sorted(p.get_emails_for_users([user.pk, user2.pk])),
+                          sorted([user.email, 'foobaz@example.com']))
+
+    def test_get_sendable_users(self):
+        from django.contrib.auth.models import User
+        from sentry.models import Project, UserOption
+
+        user = User.objects.create(username='foo', email='foo@example.com')
+        user2 = User.objects.create(username='baz', email='baz@example.com')
+        project = Project.objects.create(name='Test', slug='test', owner=user)
+        project.team.member_set.get_or_create(user=user)
+        project.team.member_set.get_or_create(user=user2)
+
+        p = MailProcessor()
+
+        # all members
+        self.assertEqual(sorted(set([user.pk, user2.pk])),
+                         sorted(p.get_sendable_users(project)))
+
+        # disabled user2
+        UserOption.objects.create(key='mail:alert', value=0, project=project, user=user2)
+        self.assertEqual(sorted(set([user.pk])),
+                         sorted(p.get_sendable_users(project)))
